@@ -2,13 +2,14 @@
 feedback = {
     submit: function(form){
         var data = {};
-        var feedback_url = $(form).attr('action');
-        $(form).find(':input').each(function(){
-            var key = $(this).attr('name');
-            var value = $(this).attr('value');
+
+        var form_array = $(form).serializeArray();
+        for (i=0;i<form_array.length;i++){
+            var key = form_array[i].name;
+            var value = form_array[i].value;
             data[key] = value;
-        });
-        
+        }
+
         $.post(feedback_url, data, function(data, textStatus){
             $(form).replaceWith(data).show();
         });
